@@ -3,11 +3,10 @@ package Yote;
 use strict;
 use warnings;
 no  warnings 'uninitialized';
-use Module::Loaded;
 
 use vars qw($VERSION);
 
-$VERSION = '1.39';
+$VERSION = '1.40';
 
 =head1 NAME
 
@@ -250,9 +249,8 @@ sub fetch {
             my $obj;
             eval {
                 my $path = $class;
-                unless( is_loaded( $class ) ) {
-                    eval("require $class");
-                    mark_as_loaded( $class );
+                unless( $INC{ $class } ) {
+                    eval("use $class");
                 }
                 $obj = $class->_instantiate( $id, $self );
             };
@@ -322,7 +320,7 @@ sub _new { #Yote::ObjStore
 sub _init {
     my $self = shift;
     for my $pkg ( qw( Yote::Obj Yote::Array Yote::Hash ) ) {
-        is_loaded( $pkg ) or mark_as_loaded( $pkg );
+        $INC{ $pkg } or eval("use $pkg");
     }
     $self->fetch_root;
     $self->stow_all;
@@ -812,6 +810,9 @@ sub _new { #new Yote::Obj
     return $obj;
 } #_new
 
+sub _store {
+    return shift->{STORE};
+}
 
 #
 # Called by the object provider; returns a Yote::Obj the object
@@ -1184,6 +1185,6 @@ __END__
        under the same terms as Perl itself.
 
 =head1 VERSION
-       Version 1.39  (May 11, 2016))
+       Version 1.40  (May 11, 2016))
 
 =cut
